# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages_robocup_ssl_geometry.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='messages_robocup_ssl_geometry.proto',
  package='',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n#messages_robocup_ssl_geometry.proto\" \n\x08Vector2f\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\"\x88\x01\n\x14SSL_FieldLineSegment\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x15\n\x02p1\x18\x02 \x02(\x0b\x32\t.Vector2f\x12\x15\n\x02p2\x18\x03 \x02(\x0b\x32\t.Vector2f\x12\x11\n\tthickness\x18\x04 \x02(\x02\x12!\n\x04type\x18\x05 \x01(\x0e\x32\x13.SSL_FieldShapeType\"\x9d\x01\n\x14SSL_FieldCircularArc\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x19\n\x06\x63\x65nter\x18\x02 \x02(\x0b\x32\t.Vector2f\x12\x0e\n\x06radius\x18\x03 \x02(\x02\x12\n\n\x02\x61\x31\x18\x04 \x02(\x02\x12\n\n\x02\x61\x32\x18\x05 \x02(\x02\x12\x11\n\tthickness\x18\x06 \x02(\x02\x12!\n\x04type\x18\x07 \x01(\x0e\x32\x13.SSL_FieldShapeType\"\xb0\x03\n\x15SSL_GeometryFieldSize\x12\x14\n\x0c\x66ield_length\x18\x01 \x02(\x05\x12\x13\n\x0b\x66ield_width\x18\x02 \x02(\x05\x12\x12\n\ngoal_width\x18\x03 \x02(\x05\x12\x12\n\ngoal_depth\x18\x04 \x02(\x05\x12\x16\n\x0e\x62oundary_width\x18\x05 \x02(\x05\x12*\n\x0b\x66ield_lines\x18\x06 \x03(\x0b\x32\x15.SSL_FieldLineSegment\x12)\n\nfield_arcs\x18\x07 \x03(\x0b\x32\x15.SSL_FieldCircularArc\x12\x1a\n\x12penalty_area_depth\x18\x08 \x01(\x05\x12\x1a\n\x12penalty_area_width\x18\t \x01(\x05\x12\x1c\n\x14\x63\x65nter_circle_radius\x18\n \x01(\x05\x12\x16\n\x0eline_thickness\x18\x0b \x01(\x05\x12#\n\x1bgoal_center_to_penalty_mark\x18\x0c \x01(\x05\x12\x13\n\x0bgoal_height\x18\r \x01(\x05\x12\x13\n\x0b\x62\x61ll_radius\x18\x0e \x01(\x02\x12\x18\n\x10max_robot_radius\x18\x0f \x01(\x02\"\x80\x03\n\x1dSSL_GeometryCameraCalibration\x12\x11\n\tcamera_id\x18\x01 \x02(\r\x12\x14\n\x0c\x66ocal_length\x18\x02 \x02(\x02\x12\x19\n\x11principal_point_x\x18\x03 \x02(\x02\x12\x19\n\x11principal_point_y\x18\x04 \x02(\x02\x12\x12\n\ndistortion\x18\x05 \x02(\x02\x12\n\n\x02q0\x18\x06 \x02(\x02\x12\n\n\x02q1\x18\x07 \x02(\x02\x12\n\n\x02q2\x18\x08 \x02(\x02\x12\n\n\x02q3\x18\t \x02(\x02\x12\n\n\x02tx\x18\n \x02(\x02\x12\n\n\x02ty\x18\x0b \x02(\x02\x12\n\n\x02tz\x18\x0c \x02(\x02\x12\x1f\n\x17\x64\x65rived_camera_world_tx\x18\r \x01(\x02\x12\x1f\n\x17\x64\x65rived_camera_world_ty\x18\x0e \x01(\x02\x12\x1f\n\x17\x64\x65rived_camera_world_tz\x18\x0f \x01(\x02\x12\x19\n\x11pixel_image_width\x18\x10 \x01(\r\x12\x1a\n\x12pixel_image_height\x18\x11 \x01(\r\"V\n\x1dSSL_BallModelStraightTwoPhase\x12\x11\n\tacc_slide\x18\x01 \x02(\x01\x12\x10\n\x08\x61\x63\x63_roll\x18\x02 \x02(\x01\x12\x10\n\x08k_switch\x18\x03 \x02(\x01\"l\n\x1aSSL_BallModelChipFixedLoss\x12\x1c\n\x14\x64\x61mping_xy_first_hop\x18\x01 \x02(\x01\x12\x1d\n\x15\x64\x61mping_xy_other_hops\x18\x02 \x02(\x01\x12\x11\n\tdamping_z\x18\x03 \x02(\x01\"\x86\x01\n\x12SSL_GeometryModels\x12:\n\x12straight_two_phase\x18\x01 \x01(\x0b\x32\x1e.SSL_BallModelStraightTwoPhase\x12\x34\n\x0f\x63hip_fixed_loss\x18\x02 \x01(\x0b\x32\x1b.SSL_BallModelChipFixedLoss\"\x8d\x01\n\x10SSL_GeometryData\x12%\n\x05\x66ield\x18\x01 \x02(\x0b\x32\x16.SSL_GeometryFieldSize\x12-\n\x05\x63\x61lib\x18\x02 \x03(\x0b\x32\x1e.SSL_GeometryCameraCalibration\x12#\n\x06models\x18\x03 \x01(\x0b\x32\x13.SSL_GeometryModels*\xdb\x02\n\x12SSL_FieldShapeType\x12\r\n\tUndefined\x10\x00\x12\x10\n\x0c\x43\x65nterCircle\x10\x01\x12\x10\n\x0cTopTouchLine\x10\x02\x12\x13\n\x0f\x42ottomTouchLine\x10\x03\x12\x10\n\x0cLeftGoalLine\x10\x04\x12\x11\n\rRightGoalLine\x10\x05\x12\x0f\n\x0bHalfwayLine\x10\x06\x12\x0e\n\nCenterLine\x10\x07\x12\x16\n\x12LeftPenaltyStretch\x10\x08\x12\x17\n\x13RightPenaltyStretch\x10\t\x12\x1f\n\x1bLeftFieldLeftPenaltyStretch\x10\n\x12 \n\x1cLeftFieldRightPenaltyStretch\x10\x0b\x12 \n\x1cRightFieldLeftPenaltyStretch\x10\x0c\x12!\n\x1dRightFieldRightPenaltyStretch\x10\r')
)

_SSL_FIELDSHAPETYPE = _descriptor.EnumDescriptor(
  name='SSL_FieldShapeType',
  full_name='SSL_FieldShapeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Undefined', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CenterCircle', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TopTouchLine', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BottomTouchLine', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LeftGoalLine', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RightGoalLine', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HalfwayLine', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CenterLine', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LeftPenaltyStretch', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RightPenaltyStretch', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LeftFieldLeftPenaltyStretch', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LeftFieldRightPenaltyStretch', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RightFieldLeftPenaltyStretch', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RightFieldRightPenaltyStretch', index=13, number=13,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1674,
  serialized_end=2021,
)
_sym_db.RegisterEnumDescriptor(_SSL_FIELDSHAPETYPE)

SSL_FieldShapeType = enum_type_wrapper.EnumTypeWrapper(_SSL_FIELDSHAPETYPE)
Undefined = 0
CenterCircle = 1
TopTouchLine = 2
BottomTouchLine = 3
LeftGoalLine = 4
RightGoalLine = 5
HalfwayLine = 6
CenterLine = 7
LeftPenaltyStretch = 8
RightPenaltyStretch = 9
LeftFieldLeftPenaltyStretch = 10
LeftFieldRightPenaltyStretch = 11
RightFieldLeftPenaltyStretch = 12
RightFieldRightPenaltyStretch = 13



_VECTOR2F = _descriptor.Descriptor(
  name='Vector2f',
  full_name='Vector2f',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='Vector2f.x', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='Vector2f.y', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=71,
)


_SSL_FIELDLINESEGMENT = _descriptor.Descriptor(
  name='SSL_FieldLineSegment',
  full_name='SSL_FieldLineSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='SSL_FieldLineSegment.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p1', full_name='SSL_FieldLineSegment.p1', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2', full_name='SSL_FieldLineSegment.p2', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thickness', full_name='SSL_FieldLineSegment.thickness', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='SSL_FieldLineSegment.type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=74,
  serialized_end=210,
)


_SSL_FIELDCIRCULARARC = _descriptor.Descriptor(
  name='SSL_FieldCircularArc',
  full_name='SSL_FieldCircularArc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='SSL_FieldCircularArc.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='center', full_name='SSL_FieldCircularArc.center', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='radius', full_name='SSL_FieldCircularArc.radius', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='a1', full_name='SSL_FieldCircularArc.a1', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='a2', full_name='SSL_FieldCircularArc.a2', index=4,
      number=5, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thickness', full_name='SSL_FieldCircularArc.thickness', index=5,
      number=6, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='SSL_FieldCircularArc.type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=370,
)


_SSL_GEOMETRYFIELDSIZE = _descriptor.Descriptor(
  name='SSL_GeometryFieldSize',
  full_name='SSL_GeometryFieldSize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='field_length', full_name='SSL_GeometryFieldSize.field_length', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_width', full_name='SSL_GeometryFieldSize.field_width', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='goal_width', full_name='SSL_GeometryFieldSize.goal_width', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='goal_depth', full_name='SSL_GeometryFieldSize.goal_depth', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boundary_width', full_name='SSL_GeometryFieldSize.boundary_width', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_lines', full_name='SSL_GeometryFieldSize.field_lines', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_arcs', full_name='SSL_GeometryFieldSize.field_arcs', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='penalty_area_depth', full_name='SSL_GeometryFieldSize.penalty_area_depth', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='penalty_area_width', full_name='SSL_GeometryFieldSize.penalty_area_width', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='center_circle_radius', full_name='SSL_GeometryFieldSize.center_circle_radius', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_thickness', full_name='SSL_GeometryFieldSize.line_thickness', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='goal_center_to_penalty_mark', full_name='SSL_GeometryFieldSize.goal_center_to_penalty_mark', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='goal_height', full_name='SSL_GeometryFieldSize.goal_height', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ball_radius', full_name='SSL_GeometryFieldSize.ball_radius', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_robot_radius', full_name='SSL_GeometryFieldSize.max_robot_radius', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=373,
  serialized_end=805,
)


_SSL_GEOMETRYCAMERACALIBRATION = _descriptor.Descriptor(
  name='SSL_GeometryCameraCalibration',
  full_name='SSL_GeometryCameraCalibration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='camera_id', full_name='SSL_GeometryCameraCalibration.camera_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='focal_length', full_name='SSL_GeometryCameraCalibration.focal_length', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='principal_point_x', full_name='SSL_GeometryCameraCalibration.principal_point_x', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='principal_point_y', full_name='SSL_GeometryCameraCalibration.principal_point_y', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distortion', full_name='SSL_GeometryCameraCalibration.distortion', index=4,
      number=5, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q0', full_name='SSL_GeometryCameraCalibration.q0', index=5,
      number=6, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q1', full_name='SSL_GeometryCameraCalibration.q1', index=6,
      number=7, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q2', full_name='SSL_GeometryCameraCalibration.q2', index=7,
      number=8, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q3', full_name='SSL_GeometryCameraCalibration.q3', index=8,
      number=9, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx', full_name='SSL_GeometryCameraCalibration.tx', index=9,
      number=10, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ty', full_name='SSL_GeometryCameraCalibration.ty', index=10,
      number=11, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tz', full_name='SSL_GeometryCameraCalibration.tz', index=11,
      number=12, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='derived_camera_world_tx', full_name='SSL_GeometryCameraCalibration.derived_camera_world_tx', index=12,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='derived_camera_world_ty', full_name='SSL_GeometryCameraCalibration.derived_camera_world_ty', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='derived_camera_world_tz', full_name='SSL_GeometryCameraCalibration.derived_camera_world_tz', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pixel_image_width', full_name='SSL_GeometryCameraCalibration.pixel_image_width', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pixel_image_height', full_name='SSL_GeometryCameraCalibration.pixel_image_height', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=808,
  serialized_end=1192,
)


_SSL_BALLMODELSTRAIGHTTWOPHASE = _descriptor.Descriptor(
  name='SSL_BallModelStraightTwoPhase',
  full_name='SSL_BallModelStraightTwoPhase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='acc_slide', full_name='SSL_BallModelStraightTwoPhase.acc_slide', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acc_roll', full_name='SSL_BallModelStraightTwoPhase.acc_roll', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='k_switch', full_name='SSL_BallModelStraightTwoPhase.k_switch', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1194,
  serialized_end=1280,
)


_SSL_BALLMODELCHIPFIXEDLOSS = _descriptor.Descriptor(
  name='SSL_BallModelChipFixedLoss',
  full_name='SSL_BallModelChipFixedLoss',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='damping_xy_first_hop', full_name='SSL_BallModelChipFixedLoss.damping_xy_first_hop', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='damping_xy_other_hops', full_name='SSL_BallModelChipFixedLoss.damping_xy_other_hops', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='damping_z', full_name='SSL_BallModelChipFixedLoss.damping_z', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1282,
  serialized_end=1390,
)


_SSL_GEOMETRYMODELS = _descriptor.Descriptor(
  name='SSL_GeometryModels',
  full_name='SSL_GeometryModels',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='straight_two_phase', full_name='SSL_GeometryModels.straight_two_phase', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chip_fixed_loss', full_name='SSL_GeometryModels.chip_fixed_loss', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1393,
  serialized_end=1527,
)


_SSL_GEOMETRYDATA = _descriptor.Descriptor(
  name='SSL_GeometryData',
  full_name='SSL_GeometryData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='field', full_name='SSL_GeometryData.field', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calib', full_name='SSL_GeometryData.calib', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='models', full_name='SSL_GeometryData.models', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1530,
  serialized_end=1671,
)

_SSL_FIELDLINESEGMENT.fields_by_name['p1'].message_type = _VECTOR2F
_SSL_FIELDLINESEGMENT.fields_by_name['p2'].message_type = _VECTOR2F
_SSL_FIELDLINESEGMENT.fields_by_name['type'].enum_type = _SSL_FIELDSHAPETYPE
_SSL_FIELDCIRCULARARC.fields_by_name['center'].message_type = _VECTOR2F
_SSL_FIELDCIRCULARARC.fields_by_name['type'].enum_type = _SSL_FIELDSHAPETYPE
_SSL_GEOMETRYFIELDSIZE.fields_by_name['field_lines'].message_type = _SSL_FIELDLINESEGMENT
_SSL_GEOMETRYFIELDSIZE.fields_by_name['field_arcs'].message_type = _SSL_FIELDCIRCULARARC
_SSL_GEOMETRYMODELS.fields_by_name['straight_two_phase'].message_type = _SSL_BALLMODELSTRAIGHTTWOPHASE
_SSL_GEOMETRYMODELS.fields_by_name['chip_fixed_loss'].message_type = _SSL_BALLMODELCHIPFIXEDLOSS
_SSL_GEOMETRYDATA.fields_by_name['field'].message_type = _SSL_GEOMETRYFIELDSIZE
_SSL_GEOMETRYDATA.fields_by_name['calib'].message_type = _SSL_GEOMETRYCAMERACALIBRATION
_SSL_GEOMETRYDATA.fields_by_name['models'].message_type = _SSL_GEOMETRYMODELS
DESCRIPTOR.message_types_by_name['Vector2f'] = _VECTOR2F
DESCRIPTOR.message_types_by_name['SSL_FieldLineSegment'] = _SSL_FIELDLINESEGMENT
DESCRIPTOR.message_types_by_name['SSL_FieldCircularArc'] = _SSL_FIELDCIRCULARARC
DESCRIPTOR.message_types_by_name['SSL_GeometryFieldSize'] = _SSL_GEOMETRYFIELDSIZE
DESCRIPTOR.message_types_by_name['SSL_GeometryCameraCalibration'] = _SSL_GEOMETRYCAMERACALIBRATION
DESCRIPTOR.message_types_by_name['SSL_BallModelStraightTwoPhase'] = _SSL_BALLMODELSTRAIGHTTWOPHASE
DESCRIPTOR.message_types_by_name['SSL_BallModelChipFixedLoss'] = _SSL_BALLMODELCHIPFIXEDLOSS
DESCRIPTOR.message_types_by_name['SSL_GeometryModels'] = _SSL_GEOMETRYMODELS
DESCRIPTOR.message_types_by_name['SSL_GeometryData'] = _SSL_GEOMETRYDATA
DESCRIPTOR.enum_types_by_name['SSL_FieldShapeType'] = _SSL_FIELDSHAPETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Vector2f = _reflection.GeneratedProtocolMessageType('Vector2f', (_message.Message,), dict(
  DESCRIPTOR = _VECTOR2F,
  __module__ = 'messages_robocup_ssl_geometry_pb2'
  # @@protoc_insertion_point(class_scope:Vector2f)
  ))
_sym_db.RegisterMessage(Vector2f)

SSL_FieldLineSegment = _reflection.GeneratedProtocolMessageType('SSL_FieldLineSegment', (_message.Message,), dict(
  DESCRIPTOR = _SSL_FIELDLINESEGMENT,
  __module__ = 'messages_robocup_ssl_geometry_pb2'
  # @@protoc_insertion_point(class_scope:SSL_FieldLineSegment)
  ))
_sym_db.RegisterMessage(SSL_FieldLineSegment)

SSL_FieldCircularArc = _reflection.GeneratedProtocolMessageType('SSL_FieldCircularArc', (_message.Message,), dict(
  DESCRIPTOR = _SSL_FIELDCIRCULARARC,
  __module__ = 'messages_robocup_ssl_geometry_pb2'
  # @@protoc_insertion_point(class_scope:SSL_FieldCircularArc)
  ))
_sym_db.RegisterMessage(SSL_FieldCircularArc)

SSL_GeometryFieldSize = _reflection.GeneratedProtocolMessageType('SSL_GeometryFieldSize', (_message.Message,), dict(
  DESCRIPTOR = _SSL_GEOMETRYFIELDSIZE,
  __module__ = 'messages_robocup_ssl_geometry_pb2'
  # @@protoc_insertion_point(class_scope:SSL_GeometryFieldSize)
  ))
_sym_db.RegisterMessage(SSL_GeometryFieldSize)

SSL_GeometryCameraCalibration = _reflection.GeneratedProtocolMessageType('SSL_GeometryCameraCalibration', (_message.Message,), dict(
  DESCRIPTOR = _SSL_GEOMETRYCAMERACALIBRATION,
  __module__ = 'messages_robocup_ssl_geometry_pb2'
  # @@protoc_insertion_point(class_scope:SSL_GeometryCameraCalibration)
  ))
_sym_db.RegisterMessage(SSL_GeometryCameraCalibration)

SSL_BallModelStraightTwoPhase = _reflection.GeneratedProtocolMessageType('SSL_BallModelStraightTwoPhase', (_message.Message,), dict(
  DESCRIPTOR = _SSL_BALLMODELSTRAIGHTTWOPHASE,
  __module__ = 'messages_robocup_ssl_geometry_pb2'
  # @@protoc_insertion_point(class_scope:SSL_BallModelStraightTwoPhase)
  ))
_sym_db.RegisterMessage(SSL_BallModelStraightTwoPhase)

SSL_BallModelChipFixedLoss = _reflection.GeneratedProtocolMessageType('SSL_BallModelChipFixedLoss', (_message.Message,), dict(
  DESCRIPTOR = _SSL_BALLMODELCHIPFIXEDLOSS,
  __module__ = 'messages_robocup_ssl_geometry_pb2'
  # @@protoc_insertion_point(class_scope:SSL_BallModelChipFixedLoss)
  ))
_sym_db.RegisterMessage(SSL_BallModelChipFixedLoss)

SSL_GeometryModels = _reflection.GeneratedProtocolMessageType('SSL_GeometryModels', (_message.Message,), dict(
  DESCRIPTOR = _SSL_GEOMETRYMODELS,
  __module__ = 'messages_robocup_ssl_geometry_pb2'
  # @@protoc_insertion_point(class_scope:SSL_GeometryModels)
  ))
_sym_db.RegisterMessage(SSL_GeometryModels)

SSL_GeometryData = _reflection.GeneratedProtocolMessageType('SSL_GeometryData', (_message.Message,), dict(
  DESCRIPTOR = _SSL_GEOMETRYDATA,
  __module__ = 'messages_robocup_ssl_geometry_pb2'
  # @@protoc_insertion_point(class_scope:SSL_GeometryData)
  ))
_sym_db.RegisterMessage(SSL_GeometryData)


# @@protoc_insertion_point(module_scope)



import socket
import struct
import json
import math
import threading
import time
from collections import deque

from google.protobuf.json_format import MessageToJson
from .protocols import messages_robocup_ssl_wrapper_pb2
import os


def get_config(config_file=None):
    if config_file:
        config = json.loads(open(config_file, 'r').read())
    else:
        config = json.loads(open('config.json', 'r').read())

    return config


class SSLVision(threading.Thread):
    def __init__(self, config_file=None):
        super(SSLVision, self).__init__()
        self.config = get_config(config_file)

        self.frame = {}
        self.last_frame = {}

        self.vision_port = int(os.environ.get('VISION_PORT', self.config['network']['vision_port']))
        self.host = os.environ.get('MULTICAST_IP', self.config['network']['multicast_ip'])

        self._fps = 0
        self._frame_times = deque(maxlen=60)

        self.callback = None

        self.kill_recieved = False

    def assign_vision(self, callback):
        self.callback = callback

    def set_fps(self):
        self._frame_times.append(time.time())
        if len(self._frame_times) <= 3:
            return
        fps_frame_by_frame = [
            (v - i) for i, v in zip(self._frame_times, list(self._frame_times)[1:])
        ]
        self._fps = len(fps_frame_by_frame) / sum(fps_frame_by_frame)

    def run(self):
        print("Starting vision...")
        self.vision_sock = self._create_socket()
        self._wait_to_connect()
        print("Vision completed!")

        while not self.kill_recieved:
            env = messages_robocup_ssl_wrapper_pb2.SSL_WrapperPacket()
            data = self.vision_sock.recv(1024)
            self.set_fps()
            env.ParseFromString(data)
            self.frame = json.loads(MessageToJson(env))

            if self.callback:
                self.callback()

    def _wait_to_connect(self):
        self.vision_sock.recv(1024)

    def _create_socket(self):
        print(f"Creating socket with address: {self.host} and port: {self.vision_port}")
        sock = socket.socket(
            socket.AF_INET,
            socket.SOCK_DGRAM,
            socket.IPPROTO_UDP
        )

        sock.setsockopt(
            socket.SOL_SOCKET,
            socket.SO_REUSEADDR, 1
        )

        sock.bind((self.host, self.vision_port))

        mreq = struct.pack(
            "4sl",
            socket.inet_aton(self.host),
            socket.INADDR_ANY
        )

        sock.setsockopt(
            socket.IPPROTO_IP,
            socket.IP_ADD_MEMBERSHIP,
            mreq
        )

        return sock


def assign_empty_values(raw_frame, field_size, team_side, last_frame=None, ball_lp=False):
    """Process vision frame placing the origin at the right edge of the field relative to your defending goal

    Parameters
    ----------
    raw_frame : dict
        The newest unprocessed frame from the SSL Vision
    field_size : tuple of float
        The width and height of the field
    team_side: {'right', 'left'}
        The side your team is playing
    last_frame: dict, optional
        The last processed frame, used as a default output when the raw_frame can't be processed
    ball_lp: bool, optional
        When true wil return the ball in the same position from the last frame if it's not on the received frame

    Returns
    -------
    dict
        The resulting frame
    """
    if raw_frame.get('detection') is None:
        return last_frame

    frame = raw_frame.get('detection')
    w, h = field_size

    frame['ball'] = {}
    if frame.get('balls'):

        if team_side == 'right':
            frame['ball']['x'] = -frame['balls'][0].get('x', 0)
            frame['ball']['y'] = -frame['balls'][0].get('y', 0)
        else:
            frame['ball']['x'] = frame['balls'][0].get('x', 0)
            frame['ball']['y'] = frame['balls'][0].get('y', 0)

        frame['ball']['x'] = frame['ball']['x'] / 1000 + w / 2
        frame['ball']['y'] = frame['ball']['y'] / 1000 + h / 2
    else:
        if ball_lp:
            frame['ball'] = last_frame['ball']
        else:
            frame['ball']['x'] = -1
            frame['ball']['y'] = -1

    for robot in frame.get("robotsYellow", []):
        if team_side == 'right':
            robot['x'] = - robot.get('x', 0)
            robot['y'] = - robot.get('y', 0)
            robot['orientation'] = robot.get('orientation', 0) + math.pi

        robot['x'] = robot.get('x', 0) / 1000 + w / 2
        robot['y'] = robot.get('y', 0) / 1000 + h / 2
        robot['robotId'] = robot.get('robotId', 0)
        robot['orientation'] = robot.get('orientation', 0)

    for robot in frame.get("robotsBlue", []):
        if team_side == 'right':
            robot['x'] = - robot.get('x', 0)
            robot['y'] = - robot.get('y', 0)
            robot['orientation'] = robot.get('orientation', 0) + math.pi

        robot['x'] = robot.get('x', 0) / 1000 + w / 2
        robot['y'] = robot.get('y', 0) / 1000 + h / 2
        robot['robotId'] = robot.get('robotId', 0)
        robot['orientation'] = robot.get('orientation', 0)

    return frame


if __name__ == "__main__":
    import time

    v = SSLVision()

    v.start()

    while True:
        time.sleep(1)
        print(v.frame)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages_robocup_ssl_wrapper.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import messages_robocup_ssl_detection_pb2 as messages__robocup__ssl__detection__pb2
from . import messages_robocup_ssl_geometry_pb2 as messages__robocup__ssl__geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='messages_robocup_ssl_wrapper.proto',
  package='',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\"messages_robocup_ssl_wrapper.proto\x1a$messages_robocup_ssl_detection.proto\x1a#messages_robocup_ssl_geometry.proto\"`\n\x11SSL_WrapperPacket\x12&\n\tdetection\x18\x01 \x01(\x0b\x32\x13.SSL_DetectionFrame\x12#\n\x08geometry\x18\x02 \x01(\x0b\x32\x11.SSL_GeometryData')
  ,
  dependencies=[messages__robocup__ssl__detection__pb2.DESCRIPTOR,messages__robocup__ssl__geometry__pb2.DESCRIPTOR,])




_SSL_WRAPPERPACKET = _descriptor.Descriptor(
  name='SSL_WrapperPacket',
  full_name='SSL_WrapperPacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection', full_name='SSL_WrapperPacket.detection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geometry', full_name='SSL_WrapperPacket.geometry', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=113,
  serialized_end=209,
)

_SSL_WRAPPERPACKET.fields_by_name['detection'].message_type = messages__robocup__ssl__detection__pb2._SSL_DETECTIONFRAME
_SSL_WRAPPERPACKET.fields_by_name['geometry'].message_type = messages__robocup__ssl__geometry__pb2._SSL_GEOMETRYDATA
DESCRIPTOR.message_types_by_name['SSL_WrapperPacket'] = _SSL_WRAPPERPACKET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SSL_WrapperPacket = _reflection.GeneratedProtocolMessageType('SSL_WrapperPacket', (_message.Message,), dict(
  DESCRIPTOR = _SSL_WRAPPERPACKET,
  __module__ = 'messages_robocup_ssl_wrapper_pb2'
  # @@protoc_insertion_point(class_scope:SSL_WrapperPacket)
  ))
_sym_db.RegisterMessage(SSL_WrapperPacket)


# @@protoc_insertion_point(module_scope)



from setuptools import find_packages, setup

setup(
    name="pySSLVision",
    packages=find_packages() + find_packages(where="./protocols"),
    version="2.0.0",
    description="Creates a network socket to communicate with the SSL Vision",
    long_description_content_type='text/markdown',
    long_description=open('README.md').read(),
    author="Project-Neon",
    author_email="projectneon@gmail.com",
    license="GNU",
    install_requires=['protobuf==3.20.3'],
)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages_robocup_ssl_detection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='messages_robocup_ssl_detection.proto',
  package='',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n$messages_robocup_ssl_detection.proto\"x\n\x11SSL_DetectionBall\x12\x12\n\nconfidence\x18\x01 \x02(\x02\x12\x0c\n\x04\x61rea\x18\x02 \x01(\r\x12\t\n\x01x\x18\x03 \x02(\x02\x12\t\n\x01y\x18\x04 \x02(\x02\x12\t\n\x01z\x18\x05 \x01(\x02\x12\x0f\n\x07pixel_x\x18\x06 \x02(\x02\x12\x0f\n\x07pixel_y\x18\x07 \x02(\x02\"\x97\x01\n\x12SSL_DetectionRobot\x12\x12\n\nconfidence\x18\x01 \x02(\x02\x12\x10\n\x08robot_id\x18\x02 \x01(\r\x12\t\n\x01x\x18\x03 \x02(\x02\x12\t\n\x01y\x18\x04 \x02(\x02\x12\x13\n\x0borientation\x18\x05 \x01(\x02\x12\x0f\n\x07pixel_x\x18\x06 \x02(\x02\x12\x0f\n\x07pixel_y\x18\x07 \x02(\x02\x12\x0e\n\x06height\x18\x08 \x01(\x02\"\xd9\x01\n\x12SSL_DetectionFrame\x12\x14\n\x0c\x66rame_number\x18\x01 \x02(\r\x12\x11\n\tt_capture\x18\x02 \x02(\x01\x12\x0e\n\x06t_sent\x18\x03 \x02(\x01\x12\x11\n\tcamera_id\x18\x04 \x02(\r\x12!\n\x05\x62\x61lls\x18\x05 \x03(\x0b\x32\x12.SSL_DetectionBall\x12*\n\rrobots_yellow\x18\x06 \x03(\x0b\x32\x13.SSL_DetectionRobot\x12(\n\x0brobots_blue\x18\x07 \x03(\x0b\x32\x13.SSL_DetectionRobot')
)




_SSL_DETECTIONBALL = _descriptor.Descriptor(
  name='SSL_DetectionBall',
  full_name='SSL_DetectionBall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='confidence', full_name='SSL_DetectionBall.confidence', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area', full_name='SSL_DetectionBall.area', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='x', full_name='SSL_DetectionBall.x', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='SSL_DetectionBall.y', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='SSL_DetectionBall.z', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pixel_x', full_name='SSL_DetectionBall.pixel_x', index=5,
      number=6, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pixel_y', full_name='SSL_DetectionBall.pixel_y', index=6,
      number=7, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=160,
)


_SSL_DETECTIONROBOT = _descriptor.Descriptor(
  name='SSL_DetectionRobot',
  full_name='SSL_DetectionRobot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='confidence', full_name='SSL_DetectionRobot.confidence', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='robot_id', full_name='SSL_DetectionRobot.robot_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='x', full_name='SSL_DetectionRobot.x', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='SSL_DetectionRobot.y', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='SSL_DetectionRobot.orientation', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pixel_x', full_name='SSL_DetectionRobot.pixel_x', index=5,
      number=6, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pixel_y', full_name='SSL_DetectionRobot.pixel_y', index=6,
      number=7, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='height', full_name='SSL_DetectionRobot.height', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=314,
)


_SSL_DETECTIONFRAME = _descriptor.Descriptor(
  name='SSL_DetectionFrame',
  full_name='SSL_DetectionFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='frame_number', full_name='SSL_DetectionFrame.frame_number', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='t_capture', full_name='SSL_DetectionFrame.t_capture', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='t_sent', full_name='SSL_DetectionFrame.t_sent', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='camera_id', full_name='SSL_DetectionFrame.camera_id', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='balls', full_name='SSL_DetectionFrame.balls', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='robots_yellow', full_name='SSL_DetectionFrame.robots_yellow', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='robots_blue', full_name='SSL_DetectionFrame.robots_blue', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=317,
  serialized_end=534,
)

_SSL_DETECTIONFRAME.fields_by_name['balls'].message_type = _SSL_DETECTIONBALL
_SSL_DETECTIONFRAME.fields_by_name['robots_yellow'].message_type = _SSL_DETECTIONROBOT
_SSL_DETECTIONFRAME.fields_by_name['robots_blue'].message_type = _SSL_DETECTIONROBOT
DESCRIPTOR.message_types_by_name['SSL_DetectionBall'] = _SSL_DETECTIONBALL
DESCRIPTOR.message_types_by_name['SSL_DetectionRobot'] = _SSL_DETECTIONROBOT
DESCRIPTOR.message_types_by_name['SSL_DetectionFrame'] = _SSL_DETECTIONFRAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SSL_DetectionBall = _reflection.GeneratedProtocolMessageType('SSL_DetectionBall', (_message.Message,), dict(
  DESCRIPTOR = _SSL_DETECTIONBALL,
  __module__ = 'messages_robocup_ssl_detection_pb2'
  # @@protoc_insertion_point(class_scope:SSL_DetectionBall)
  ))
_sym_db.RegisterMessage(SSL_DetectionBall)

SSL_DetectionRobot = _reflection.GeneratedProtocolMessageType('SSL_DetectionRobot', (_message.Message,), dict(
  DESCRIPTOR = _SSL_DETECTIONROBOT,
  __module__ = 'messages_robocup_ssl_detection_pb2'
  # @@protoc_insertion_point(class_scope:SSL_DetectionRobot)
  ))
_sym_db.RegisterMessage(SSL_DetectionRobot)

SSL_DetectionFrame = _reflection.GeneratedProtocolMessageType('SSL_DetectionFrame', (_message.Message,), dict(
  DESCRIPTOR = _SSL_DETECTIONFRAME,
  __module__ = 'messages_robocup_ssl_detection_pb2'
  # @@protoc_insertion_point(class_scope:SSL_DetectionFrame)
  ))
_sym_db.RegisterMessage(SSL_DetectionFrame)


# @@protoc_insertion_point(module_scope)
